AliPlayerFullScreenWidget class

播放器全屏视图

纯全屏壳:只负责全屏特有逻辑(屏幕方向、系统 UI、返回键处理)。 不关心内容物的参数,由调用方组装 child。 不创建新控制器、不 configure、不销毁控制器(控制器归 AliPlayerWidget 管理)。

Fullscreen shell widget that handles orientation, system UI, and back button. Content is provided via child by the caller.

Inheritance

Constructors

AliPlayerFullScreenWidget({required AliPlayerWidgetController controller, required Widget child, Key? key})
const

Properties

child Widget
全屏显示的内容
final
controller AliPlayerWidgetController
共享的播放器控制器(用于退出全屏状态切换)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AliPlayerFullScreenWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited