playbackSpeeds property
自定义可选的播放速度列表。
Custom playback speed options.
建议速度范围控制在 0.3 到 3.0 之间,但不强制限制。 所有值必须大于 0,否则会触发断言错误。
建议列表中包含 1.0(正常速度),以确保设置面板中的 选中状态与默认播放速度一致。
Recommended speed range is 0.3 to 3.0, but not strictly enforced. All values must be greater than 0, otherwise an assertion error will be triggered.
It is recommended to include 1.0 (normal speed) in the list to ensure the selected state in the settings panel matches the default playback speed.
默认值为 SettingConstants.speedOptions。
Defaults to SettingConstants.speedOptions.
Implementation
final List<double> playbackSpeeds;