AndroidViewType enum

Android 播放器视图类型

Android player view type

仅对 Android 平台生效,iOS 平台会忽略此配置。 Only takes effect on Android; iOS ignores this configuration.

Inheritance
Available extensions

Values

surfaceView → const AndroidViewType

SurfaceView 渲染

性能更优,但不支持动画变换和透明背景。

Better performance, but does not support animated transitions or transparent backgrounds.

textureView → const AndroidViewType

TextureView 渲染

支持动画变换和透明背景,兼容性更好。

Supports animated transitions and transparent backgrounds with better compatibility.

displayView → const AndroidViewType

DisplayView 渲染

基于 AliDisplayView 的视图类型。

View type based on AliDisplayView.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPlayerViewType() AliPlayerViewTypeForAndroid
转换为底层 SDK 的视图类型
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultValue → const AndroidViewType
默认视图类型
values → const List<AndroidViewType>
A constant List of the values in this enum, in order of their declaration.