MirrorMode class

*@brief Mirroring mode/

Constructors

MirrorMode()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

MIRROR_MODE_HORIZONTAL → const int
MIRROR_MODE_NONE → const int
MIRROR_MODE_VERTICAL → const int