SlotWidgetBuilder typedef

  1. @Deprecated('Use SlotWidgetBuilderWithController instead. ' 'The new version provides a controller parameter for fullscreen mode support.')
SlotWidgetBuilder = Widget Function(BuildContext context)

插槽构建器类型定义(已废弃)

Slot builder type definition (deprecated)

已废弃: 请使用 SlotWidgetBuilderWithController 替代。 新版本提供了 controller 参数,确保在全屏模式下也能正确控制播放器。

Deprecated: Use SlotWidgetBuilderWithController instead. The new version provides a controller parameter to ensure correct player control in fullscreen mode.

Implementation

@Deprecated('Use SlotWidgetBuilderWithController instead. '
    'The new version provides a controller parameter for fullscreen mode support.')
typedef SlotWidgetBuilder = Widget Function(BuildContext context);