VidStsVideoSource class

VidSts 类型的视频源

通过VID和STS令牌播放视频的资源类型。

VidSts-based Video Source

Resource type for playing videos via VID and STS token.

Inheritance

Constructors

VidStsVideoSource({required String vid, required String accessKeyId, required String accessKeySecret, required String securityToken, required String region})
构造函数

Properties

accessKeyId String
访问密钥ID
final
accessKeySecret String
访问密钥密文
final
hashCode int
The hash code for this object.
no setterinherited
mediaId String
获取媒体唯一标识
no setteroverride
region String
区域信息
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityToken String
安全令牌
final
sourceType SourceType
获取视频源类型
no setteroverride
vid String
视频唯一标识符
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
转换为可用于播放器的配置映射
override
toString() String
A string representation of this object.
inherited
validate() bool
验证当前资源配置是否有效
override

Operators

operator ==(Object other) bool
The equality operator.
inherited