UrlVideoSource class

URL 类型的视频源

通过直接URL播放视频的资源类型。

URL-based Video Source

Resource type for playing videos via direct URL.

Inheritance

Constructors

UrlVideoSource({required String url})
构造函数

Properties

hashCode → int
The hash code for this object.
no setterinherited
isVidSource → bool
是否为 VID 源
no setterinherited
mediaId → String
获取媒体唯一标识
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → SourceType
获取视频源类型
no setteroverride
url → String
视频URL地址
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
转换为可用于播放器的配置映射
override
toString() → String
A string representation of this object.
override
validate() → bool
验证当前资源配置是否有效
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited