VideoSource class abstract

视频播放源基类

定义了所有播放源类型的共同接口,支持不同类型的视频资源播放。

Video Playback Source Base Class

Defines the common interface for all playback source types, supporting different types of video resources.

Implementers

Constructors

VideoSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isVidSource → bool
是否为 VID 源
no setter
mediaId → String
获取媒体唯一标识
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceType → SourceType
获取视频源类型
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
转换为可用于播放器的配置映射
toString() → String
A string representation of this object.
inherited
validate() → bool
验证当前资源配置是否有效

Operators

operator ==(Object other) → bool
The equality operator.
inherited