PlayerLocalizations class

播放器本地化类

Player localizations class.

Constructors

PlayerLocalizations(Locale locale)

Properties

hashCode int
The hash code for this object.
no setterinherited
locale Locale
当前语言
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
t(String key, [Map<String, dynamic>? args]) String
获取翻译
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited