PlayerLocalizationsDelegate class

播放器本地化代理

Flutter LocalizationsDelegate implementation for the player.

This allows the player to respond to app-level locale changes automatically when used with MaterialApp's localizationsDelegates.

Usage / 使用示例

MaterialApp(
  localizationsDelegates: const [
    PlayerLocalizationsDelegate(),
    GlobalMaterialLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ],
  supportedLocales: AliPlayerWidgetGlobalSetting.supportedLocales,
  home: const VideoPage(),
);
Inheritance

Constructors

PlayerLocalizationsDelegate()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
The type of the object returned by the load method, T by default.
no setterinherited

Methods

isSupported(Locale locale) bool
Whether resources for the given locale can be loaded by this delegate.
override
load(Locale locale) Future<PlayerLocalizations>
Start loading the resources for locale. The returned future completes when the resources have finished loading.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldReload(covariant LocalizationsDelegate<PlayerLocalizations> old) bool
Returns true if the resources for this delegate should be loaded again by calling the load method.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited