AliPlayerSettingsPanelManager class

设置面板管理器

统一管理播放器设置面板的显示逻辑,支持横竖屏自动切换。 所有设置相关的状态直接使用 AliPlayerWidgetController 的 notifier, 确保横竖屏数据一致性。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showQualityPanel({required BuildContext context, required AliPlayerWidgetController controller}) Future<void>
显示清晰度面板(横屏底部按钮触发)
showSettingsPanel({required BuildContext context, required AliPlayerWidgetController controller, required SceneType sceneType, required Map<SlotType, Set<String>>? hiddenSlotElements, required SafeValueNotifier<bool> isShowExternalSubtitle}) Future<void>
显示设置面板(自动根据 orientation 选择横竖屏样式)
showSpeedPanel({required BuildContext context, required AliPlayerWidgetController controller}) Future<void>
显示倍速面板(横屏底部按钮触发)