ScenarioManager class

播放器能力识别管理

Player capability recognition manager.

内部管理类,统一负责能力识别数据生成,用于播放体验优化和问题诊断。

Internal management class responsible for generating capability recognition data, used for playback experience optimization and issue diagnosis.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildScenarioFlag({required SceneType sceneType, required SourceType sourceType}) String
生成能力识别数据

Constants

globalExtraData → const String
能力识别数据(播放体验优化,请勿覆盖)