BottomBarElements class

底部栏元素 key 常量

Bottom bar element key constants.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullscreen → const String
全屏切换按钮
play → const String
播放/暂停按钮
progress → const String
进度条
refresh → const String
直播刷新按钮
subtitle → const String
外挂字幕切换按钮