CenterDisplayElements class

中心显示元素 key 常量

Center display element key constants.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

brightness → const String
亮度滑块
speed → const String
倍速显示
volume → const String
声音滑块