SettingMenuElements class
设置菜单元素 key 常量
Setting menu element key constants.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- brightness → const String
- 亮度
- loop → const String
- 循环播放
- mirrorMode → const String
- 镜像模式
- mute → const String
- 静音播放
- rotateMode → const String
- 旋转模式
- scaleMode → const String
- 渲染填充模式
- settingsButton → const String
- 设置按钮
- speed → const String
- 倍速
- subtitle → const String
- 字幕开关
- trackInfo → const String
- 清晰度
- volume → const String
- 声音