name property
String
get
name
策略唯一标识,用于注册/注销和调试日志
Unique identifier for the strategy, used for registration and debug logs.
Implementation
String get name;
策略唯一标识,用于注册/注销和调试日志
Unique identifier for the strategy, used for registration and debug logs.
String get name;