onFirstFrame property
首帧渲染完成回调
Called when the first frame is rendered, with elapsed duration from prepare() call.
Implementation
final void Function(Duration cost)? onFirstFrame;
首帧渲染完成回调
Called when the first frame is rendered, with elapsed duration from prepare() call.
final void Function(Duration cost)? onFirstFrame;