onPrepared property
数据源准备完成回调
Called when player prepared, with elapsed duration from prepare() call.
Implementation
final void Function(Duration cost)? onPrepared;
数据源准备完成回调
Called when player prepared, with elapsed duration from prepare() call.
final void Function(Duration cost)? onPrepared;