stutterThreshold property
卡顿阈值,低于此时长的 loading 不计入卡顿
Loading durations shorter than this threshold are not counted as stutter.
Implementation
final Duration stutterThreshold;
卡顿阈值,低于此时长的 loading 不计入卡顿
Loading durations shorter than this threshold are not counted as stutter.
final Duration stutterThreshold;