CustomSubtitleBuilder class

自定义字幕构建器,允许开发者通过自定义函数完全控制字幕的渲染方式。

当 customBuilder 为 null 时,回退到 DefaultSubtitleBuilder。

Custom subtitle builder that allows developers to fully control subtitle rendering through a custom function.

When customBuilder is null, falls back to DefaultSubtitleBuilder.

Implemented types

Constructors

CustomSubtitleBuilder({Widget customBuilder(BuildContext context, Subtitle subtitle, SubtitleConfig config)?})
创建自定义字幕构建器。

Properties

customBuilder → Widget Function(BuildContext context, Subtitle subtitle, SubtitleConfig config)?
自定义字幕构建函数。
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, Subtitle subtitle, SubtitleConfig config) → Widget
根据字幕数据和配置构建字幕 Widget。
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited