SubtitleBuilder class abstract

字幕构建器接口,定义字幕 Widget 的构建合约。

是字幕渲染的抽象层,内置实现为 DefaultSubtitleBuilder, 也可通过 CustomSubtitleBuilder 自定义渲染方式。

Subtitle builder interface that defines the contract for building subtitle widgets.

Serves as the abstraction layer for subtitle rendering. The built-in implementation is DefaultSubtitleBuilder, and custom rendering can be achieved via CustomSubtitleBuilder.

Implementers

Constructors

SubtitleBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, Subtitle subtitle, SubtitleConfig config) Widget
根据字幕数据和配置构建字幕 Widget。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited