position property
字幕位置偏移
Subtitle position offset within the player area.
Uses EdgeInsets to define the offset from each edge.
Only bottom, left, and right are used by the subtitle widget.
Implementation
final EdgeInsets position;
字幕位置偏移
Subtitle position offset within the player area.
Uses EdgeInsets to define the offset from each edge.
Only bottom, left, and right are used by the subtitle widget.
final EdgeInsets position;