PlayerIcons class abstract final

播放器图标文件名常量

命名规则:ic_ 前缀 + 小写下划线,状态后缀 _on/_off/_done/_exit

格式选择:SVG 首选(无需多分辨率),PNG 需提供 1x/2x/3x 三套

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

back → const String
返回按钮
brightness → const String
亮度控制
download → const String
下载按钮
fullScreen → const String
全屏控制
pause → const String
暂停按钮
pausePortrait → const String
暂停按钮(竖屏样式)
play → const String
播放按钮
playPortrait → const String
播放按钮(竖屏样式)
refresh → const String
刷新按钮
settings → const String
设置按钮
snapshot → const String
截图按钮
speedControl → const String
倍速控制
statusError → const String
播放器状态 错误
statusInfo → const String
播放器状态 提示
statusLoading → const String
播放器状态 加载中
statusSuccess → const String
播放器状态 成功
subtitleClose → const String
字幕显示关闭按钮
subtitleOpen → const String
字幕显示开启按钮
volume → const String
声音控制