AliPlayerSettingsPanelBase class

Inheritance

Constructors

AliPlayerSettingsPanelBase({Key? key, required double? itemHeight, required List<SettingItem> settingItems, required Color backgroundColor, required Color panelColor, required Color dividerColor, required EdgeInsetsGeometry dividerMargin, EdgeInsetsGeometry outerPadding = const EdgeInsets.symmetric(horizontal: PlayerStyles.kSettingPanelPaddingAll), EdgeInsetsGeometry listPadding = EdgeInsets.zero, SettingItemTapCallback? onRowTap, required bool useCard, double borderRadius = 0, bool shrinkWrap = true})
const

Properties

backgroundColor Color
final
borderRadius double
useCard=false 时可用
final
dividerColor Color
final
dividerMargin EdgeInsetsGeometry
分割线间距
final
hashCode int
The hash code for this object.
no setterinherited
itemHeight double?
item 项高度
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listPadding EdgeInsetsGeometry
final
onRowTap SettingItemTapCallback?
final
outerPadding EdgeInsetsGeometry
final
panelColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settingItems List<SettingItem>
final
shrinkWrap bool
true: 高度自适应(竖屏); false: 高度占满(横屏)
final
useCard bool
竖屏 true(用 Card),横屏 false(不要 Card)
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited