SettingItem<T> class

Constructors

SettingItem({String? elementKey, required SettingItemType type, required String title, List<Object?> tags = const [], String tagToDisplayText(Object? tag)?, ValueListenable<bool>? switchListenable, ValueChanged<bool>? onSwitchChanged, ValueListenable<Object?>? selectedTagListenable, ValueChanged<Object?>? onTagTap})
const

Properties

elementKey String?
元素的唯一标识 key,对应 [SettingMenuElements.xxx]
final
hashCode int
The hash code for this object.
no setterinherited
onSwitchChanged ValueChanged<bool>?
switch 回调
final
onTagTap ValueChanged<Object?>?
tag 点击回调
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedTagListenable ValueListenable<Object?>?
final
switchListenable ValueListenable<bool>?
统一由外部 state 提供 switch 的受控值;为 null 表示本行不展示开关
final
tags List<Object?>
设置项内容
final
tagToDisplayText String Function(Object? tag)?
tag 值转换为显示文本的函数
final
title String
设置项标题
final
type SettingItemType
设置项类型
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited