BottomBarWidget class

播放器自定义底部栏组件

Inheritance

Constructors

BottomBarWidget({Key? key, required SharedAnimationManager animationManager, required AliPlayerWidgetController controller, required SceneType sceneType, required bool isPlaying, required bool isShowExternalSubtitle, required Duration currentPosition, required Duration totalDuration, required Duration bufferedPosition, required VoidCallback? onSubtitlePressed, List<ChapterInfo> chapterInfoList = const [], VoidCallback? onPlayIconPressed, VoidCallback? onReplayIconPressed, VoidCallback? onFullScreenPressed, ValueChanged<Duration>? onDragUpdate, ValueChanged<Duration>? onDragEnd, ValueChanged<Duration>? onSeekEnd, required bool isShowExternalSubtitleBtn, Orientation orientation = Orientation.portrait})
构造函数
const

Properties

animationManager → SharedAnimationManager
共享动画控制器
finalinherited
bufferedPosition → Duration
已缓冲的位置
final
chapterInfoList → List<ChapterInfo>
章节数据
final
controller → AliPlayerWidgetController
播放器控制器
final
currentPosition → Duration
当前播放位置
final
hashCode → int
The hash code for this object.
no setterinherited
isPlaying → bool
播放/暂停按钮的状态
final
isShowExternalSubtitle → bool
外挂字幕的显示状态
final
isShowExternalSubtitleBtn → bool
外挂字幕按钮显示状态
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDragEnd → ValueChanged<Duration>?
拖拽结束时触发的回调
final
onDragUpdate → ValueChanged<Duration>?
拖拽过程中触发的回调
final
onFullScreenPressed → VoidCallback?
全屏切换按钮点击回调
final
onPlayIconPressed → VoidCallback?
播放/暂停按钮点击回调
final
onReplayIconPressed → VoidCallback?
刷新按钮点击回调
final
onSeekEnd → ValueChanged<Duration>?
seek 结束时触发的回调
final
onSubtitlePressed → VoidCallback?
外挂字幕显示回调
final
orientation → Orientation
orientation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sceneType → SceneType
播放器场景类型
final
totalDuration → Duration
视频总时长
final

Methods

buildContent(BuildContext context) → Widget
子类需要实现的方法:构建主体内容
override
buildWrapper(BuildContext context, Widget child) → Widget
子类可重写此方法,为动画内容提供外层包装(如 Positioned 定位)
override
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SharedAnimationWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited