SharedAnimationManager class

共享动画控制器管理类

Mixed-in types

Constructors

SharedAnimationManager(TickerProvider vsync)
构造函数,初始化动画控制器和透明度动画。

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isDisposed → bool
是否已销毁
no setter
isVisible → bool
是否可见
no setter
opacityAnimation → Animation<double>
获取透明度动画
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
hide() → void
隐藏动画
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
show() → void
显示动画
toggle() → void
切换显隐状态
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited