CustomVideoSlider class

播放器进度条控件,用于显示视频播放进度和缓冲进度

提供拖拽和点击功能以调整播放位置,并支持边界振动反馈。 内部使用 CustomPaint 绘制,不依赖 Material Slider。

Inheritance

Constructors

CustomVideoSlider({Key? key, required Duration currentPosition, required Duration totalDuration, required Duration bufferedPosition, ValueChanged<Duration>? onDragUpdate, ValueChanged<Duration>? onDragEnd, ValueChanged<Duration>? onSeekEnd, Orientation orientation = Orientation.portrait, List<double>? chapterMarkerPositions, ValueChanged<double>? onMarkerTap})
const

Properties

bufferedPosition → Duration
已缓冲的位置
final
chapterMarkerPositions → List<double>?
章节标记点归一化位置列表(0.0 ~ 1.0)
final
currentPosition → Duration
当前播放位置
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDragEnd → ValueChanged<Duration>?
拖拽结束时触发的回调
final
onDragUpdate → ValueChanged<Duration>?
拖拽过程中触发的回调
final
onMarkerTap → ValueChanged<double>?
章节标记点击回调(传入归一化位置 0.0 ~ 1.0)
final
onSeekEnd → ValueChanged<Duration>?
seek结束时触发的回调
final
orientation → Orientation
orientation 默认样式控制
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalDuration → Duration
视频总时长
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CustomVideoSlider>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited