onMarkerTap property
章节标记点击回调(传入归一化位置 0.0 ~ 1.0)
Callback when a chapter marker is tapped, with the normalized position.
Implementation
final ValueChanged<double>? onMarkerTap;
章节标记点击回调(传入归一化位置 0.0 ~ 1.0)
Callback when a chapter marker is tapped, with the normalized position.
final ValueChanged<double>? onMarkerTap;