PlayControlWidget class

播放器控制控件

Player Control Widget

支持通过 hiddenSlotElements 禁用特定手势交互。 当手势对应的元素 key 被添加到隐藏配置中时,该手势将被禁用。

Supports disabling specific gesture interactions via hiddenSlotElements. When a gesture's element key is added to the hidden configuration, that gesture will be disabled.

Inheritance

Constructors

PlayControlWidget({Key? key, bool autoHide = true, ValueChanged<bool>? onVisibilityChanged, VoidCallback? onSingleTap, VoidCallback? onDoubleTap, VoidCallback? onLongPressStart, VoidCallback? onLongPressEnd, ValueChanged<double>? onHorizontalDragUpdate, ValueChanged<double>? onHorizontalDragEnd, ValueChanged<double>? onLeftVerticalDragUpdate, ValueChanged<double>? onLeftVerticalDragEnd, ValueChanged<double>? onRightVerticalDragUpdate, ValueChanged<double>? onRightVerticalDragEnd, Duration autoHideControlsDuration = SettingConstants.defaultAutoHideControlsDuration})
const

Properties

autoHide → bool
Whether to auto-hide the control
final
autoHideControlsDuration → Duration
播放控件自动隐藏的持续时间
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDoubleTap → VoidCallback?
final
onHorizontalDragEnd → ValueChanged<double>?
final
onHorizontalDragUpdate → ValueChanged<double>?
final
onLeftVerticalDragEnd → ValueChanged<double>?
final
onLeftVerticalDragUpdate → ValueChanged<double>?
final
onLongPressEnd → VoidCallback?
final
onLongPressStart → VoidCallback?
final
onRightVerticalDragEnd → ValueChanged<double>?
final
onRightVerticalDragUpdate → ValueChanged<double>?
final
onSingleTap → VoidCallback?
Callbacks for various gestures
final
onVisibilityChanged → ValueChanged<bool>?
回调函数:通知外部控件是否可见
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<PlayControlWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited