showInLandscapePanel property
是否在横屏设置面板中显示
Whether this item is visible in the landscape settings panel.
Implementation
final bool showInLandscapePanel;
是否在横屏设置面板中显示
Whether this item is visible in the landscape settings panel.
final bool showInLandscapePanel;