showInPortraitPanel property
是否在竖屏设置面板中显示
Whether this item is visible in the portrait settings panel.
Implementation
final bool showInPortraitPanel;
是否在竖屏设置面板中显示
Whether this item is visible in the portrait settings panel.
final bool showInPortraitPanel;