SettingItemGroup enum

设置项分组,用于竖屏设置面板的分段显示

Setting item group for sectioned display in portrait settings panel.

Inheritance
Available extensions

Values

subtitle → const SettingItemGroup

字幕相关设置

Subtitle-related settings.

playback → const SettingItemGroup

播放控制相关设置(倍速、清晰度等)

Playback control settings (speed, quality, etc.).

toggles → const SettingItemGroup

开关类设置(循环、静音等)

Toggle settings (loop, mute, etc.).

display → const SettingItemGroup

显示模式设置(镜像、渲染、旋转等)

Display mode settings (mirror, scale, rotate, etc.).

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SettingItemGroup>
A constant List of the values in this enum, in order of their declaration.