SettingPanelWidget class

设置面板基础组件,承载所有面板的公共字段与构建逻辑。

竖屏子类 PortraitSettingPanel 通过继承预设参数; 横屏子类 LandScapeSettingPanel 继承并在外层添加高斯模糊。

Base settings panel widget that holds common fields and build logic.

Portrait subclass PortraitSettingPanel inherits with preset parameters; landscape subclass LandScapeSettingPanel inherits and wraps with an outer backdrop blur.

Inheritance
Implementers

Constructors

SettingPanelWidget({Key? key, required double? itemHeight, required List<SettingItem> settingItems, required Color backgroundColor, required Color panelColor, required Color dividerColor, required EdgeInsetsGeometry dividerMargin, EdgeInsetsGeometry outerPadding = const EdgeInsets.symmetric(horizontal: PlayerStyles.kSettingPanelPaddingAll), EdgeInsetsGeometry listPadding = EdgeInsets.zero, SettingItemTapCallback? onRowTap})
const

Properties

backgroundColor → Color
背景色
final
dividerColor → Color
分割线色
final
dividerMargin → EdgeInsetsGeometry
分割线间距
final
hashCode → int
The hash code for this object.
no setterinherited
itemHeight → double?
item 项高度
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listPadding → EdgeInsetsGeometry
列表边距
final
onRowTap → SettingItemTapCallback?
点击回调
final
outerPadding → EdgeInsetsGeometry
外边距
final
panelColor → Color
面板色
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settingItems → List<SettingItem>
设置项
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited