FormatUtil class

格式化工具类

Format util

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

formatBps(int bps) String
格式化网络速度
formatDuration(Duration duration) String
格式化时间 duration 为 "HH:mm:ss" 或 "mm:ss" 格式
formatMirrorMode(int mirrorMode) String
格式化镜像模式
formatRotate(int degree) String
格式化旋转角度
formatScaleMode(int scaleMode) String
格式化渲染填充模式
formatSpeed(double speed) String
格式化倍速显示