PlayStateShowUtil class

播放状态提示工具类

Constructors

PlayStateShowUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

error(BuildContext context, {String? message, String? code, Duration duration = const Duration(seconds: 3)}) → void
便捷方法:错误状态 (默认3秒后消失)
hide() → void
手动隐藏
info(BuildContext context, {String? message, String? code, Duration duration = const Duration(seconds: 2)}) → void
便捷方法:信息状态 (默认2秒后消失)
loading(BuildContext context, {String? message, Duration? duration}) → void
便捷方法:加载状态
show(BuildContext context, {required PlayStatus widgetStatus, String? statusMessage, String? statusCode, Duration? duration = const Duration(seconds: 2)}) → void
显示播放状态
success(BuildContext context, {String? message, String? code, Duration duration = const Duration(seconds: 2)}) → void
便捷方法:成功状态 (默认2秒后消失)