DefaultSlotFactory class
内置插槽的默认构建器注册表。 Default builder registry for built-in slots.
将每个 SlotType 映射到对应的顶层构建函数, 通过闭包将 SlotBuildContext 绑定到第一个参数。
Maps each SlotType to its corresponding top-level builder function, binding SlotBuildContext to the first parameter via closure.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createDefaultBuilders(
SlotBuildContext ctx) → Map< SlotType, SlotBuilder> - 创建内置插槽构建器映射。