PlayControlElements class
播放控制手势元素 key 常量
Play control gesture element key constants.
注意:这些元素用于控制手势交互的禁用,而非 UI 元素的隐藏。 当某个手势被添加到 hiddenSlotElements 中时,该手势将被禁用。
Note: These elements control gesture interaction disabling, not UI element hiding. When a gesture is added to hiddenSlotElements, that gesture will be disabled.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- doubleTap → const String
- 双击手势(切换播放状态)
- horizontalDrag → const String
- 水平拖动手势(seek 调整进度)
- leftVerticalDrag → const String
- 左侧垂直拖动手势(调整亮度)
- longPress → const String
- 长按手势(倍速播放)
- rightVerticalDrag → const String
- 右侧垂直拖动手势(调整音量)
- singleTap → const String
- 单击手势(显示/隐藏控制栏 + 切换播放状态)