StutterInfo class
卡顿统计信息
Contains stutter detection statistics.
Constructors
- StutterInfo({required int stutterCount, required Duration totalStutterDuration, required Duration effectivePlayDuration})
-
const
Properties
- effectivePlayDuration → Duration
-
有效播放时长(不含卡顿)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stutterCount → int
-
卡顿次数
final
- stutterRate → double
-
卡顿率 = 卡顿时长 / (有效播放时长 + 卡顿时长)
no setter
- totalStutterDuration → Duration
-
总卡顿时长
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited