Subtitles class
字幕集合,管理多条字幕轨道。
提供字幕的增删查操作,内部维护一个 Subtitle 列表。
Subtitle collection that manages multiple subtitle tracks.
Provides add, remove, and query operations for subtitles, maintaining an internal list of Subtitle entries.
Properties
Methods
-
addSubtitle(
Subtitle subtitle) → void - 添加一条字幕。
-
getByTrackIndex(
int trackIndex) → List< Subtitle> - 根据轨道索引获取字幕。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeSubtitle(
int trackIndex) → List< Subtitle> - 根据轨道索引移除字幕。
-
toString(
) → String -
返回当前字幕集合的字符串表示,包含内部字幕列表。
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited