RightWheelPanel<T> class
右侧列表选择面板(横屏页面底部按钮弹出)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- RightWheelPanel
Constructors
-
RightWheelPanel(List<
T> itemTitles, {Key? key, required ValueChanged<T> onSelected, int initialIndex = 0, String displayFormatter(T item)?}) -
const
Properties
- displayFormatter → String Function(T item)?
-
选项显示格式化函数(允许为空,为空时使用默认的 toString() 方法)。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialIndex → int
-
初始选中下标
final
-
itemTitles
→ List<
T> -
设置项列表(展示时优先使用 displayFormatter,未提供时回退到 toString())。
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onSelected
→ ValueChanged<
T> -
点击某项后的回调
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< RightWheelPanel< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited